@@ -103,10 +103,11 @@ def generate_traj(args, gen=False):
             'period2': 'mcmc-ex1-s469999.pkl', 
             'GL': 'traj-{}.pkl'.format(19999999)
         }
+        
+        if model in AUX_FNAME: 
+            url = "https://drive.google.com/uc?id={}".format(AUX_URL[model])
 
-        url = "https://drive.google.com/uc?id={}".format(AUX_URL[model])
+            fname = AUX_FNAME[model]
 
-        fname = AUX_FNAME[model]
-
-        fname = os.path.join("./", fname)
-        gdown.download(url, fname, quiet=False)
+            fname = os.path.join("./", fname)
+            gdown.download(url, fname, quiet=False)
