@@ -292,7 +292,7 @@ class neuralsampler:
             grid_x = np.linspace(-2, 1, N_vis_sqrt)
             grid_y = np.linspace(-0.5, 2.5, N_vis_sqrt)
 
-            fname = "{}_d{}.pkl".format(physys, 2)
+            fname = "{}_d{}.pkl".format(physys, dim)
             # hack temporarily (Sun 09/05/2021 15:53)
             fname = os.path.join("./dataset/traj", fname)
             x_data = load(fname)
@@ -303,7 +303,7 @@ class neuralsampler:
 
             assert dim >= 2
 
-            x_vis_np = np.concatenate([x_vis_np, np.zeros((N_vis, dim-2))], axis=1)
+            x_vis_np = np.concatenate([x_vis_np[:, :2], np.zeros((N_vis, dim-2))], axis=1)
             assert x_vis_np.shape[0] == N_vis and x_vis_np.shape[1] == dim
 
             grid_interpolate_map = lambda data_np: griddata((xi_vis, yi_vis), data_np, (grid_x[None,:], grid_y[:,None]), method='cubic')
