@@ -27,6 +27,18 @@ PHYSYS = {"mb": MuellerPotential, "dw": Doublewell, "gaussian": Gaussian}
 # TODO shall we do the small function for each model here?
 
 
+def get_current_dir_or_parent(fpath): 
+    # Say /global/scratch/users/jiahaoyao/research/mike/neuralsampler,
+    # we want to find the /global/scratch/users/jiahaoyao/research/
+    cwd = os.getcwd()
+    while cwd != '/': 
+        if os.path.basename(cwd) == fpath:
+            break
+        cwd =  os.path.dirname(cwd)
+    return cwd
+
+cwd = get_current_dir_or_parent('neuralsampler')
+
 def generate_anim(args):
     # generate animation of the learning process
     # choice: gaussian, dw, mb
@@ -78,14 +90,15 @@ def generate_anim(args):
 
         #TODO: change these hard code parts!
         # do u want to unify this? 
-        _x_new = load('/home/jimmy/Downloads/colab_paritition/traj_p00000/traj-{}.pkl'.format(19999999))
+        _x_new = load(os.path.join(cwd, 'traj-{}.pkl'.format(19999999)))
         data_gt = _x_new['y']
         react_coord_gt = np.mean(data_gt, axis=1)
     
         # this is for the init measure, delete this 
-        X_init = load('/media/jimmy/TITAN1/ScratchGym/neuralsampler_all_in_one/dataset/init/{}_d{}.pkl'.format(physys, dim))
+        # hack (change to use the traj instead of the init) [Wed 09/08/2021 21:14]
+        X_init = load('dataset/traj/{}_d{}.pkl'.format(physys, dim))
         if isinstance(X_init, dict):
-            X_init = X_init['xx']
+            X_init = X_init['x']
 
         X_init=X_init[:10000, :]
         X_marginal = X_init.mean(1)
@@ -95,9 +108,9 @@ def generate_anim(args):
 
         #TODO: change these hard code parts!
         if physys == 'period': 
-            X_history = load('/media/jimmy/TITAN1/ScratchGym/neuralsampler_period/example1/mcmc-ex1-s3909999.pkl')
+            X_history = load(os.path.join(cwd, 'mcmc-ex1-s3909999.pkl'))
         else: 
-            X_history = load('/media/jimmy/TITAN1/ScratchGym/neuralsampler_period/example2/data/mcmc-ex1-s469999.pkl')
+            X_history = load(os.path.join(cwd, 'mcmc-ex1-s469999.pkl'))
 
         data_gt = np.concatenate(X_history[-10000:], 0)
 
@@ -211,7 +224,7 @@ def generate_anim(args):
                 
                 camera.snap()
 
-        elif _physys == 'period': 
+        elif _physys.startswith('period'): 
             # this is for the period case 
             for X, Y, Impsamp_ratio, D in tzip(X_list, Y_list, Impsamp_ratio_list, D_list):
                 ax = axes[0]
